@@ -1,19 +1,8 @@
-/********************************************************************
-Copyright 2019 Roman Gilg <subdiff@gmail.com>
+/*
+    SPDX-FileCopyrightText: 2019 Roman Gilg <subdiff@gmail.com>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef COMMON_CONTROL_H
 #define COMMON_CONTROL_H
 
@@ -107,6 +96,11 @@ public:
     void setVrrPolicy(const KScreen::OutputPtr &output, const KScreen::Output::VrrPolicy value);
     void setVrrPolicy(const QString &outputId, const QString &outputName, const KScreen::Output::VrrPolicy value);
 
+    KScreen::Output::RgbRange getRgbRange(const KScreen::OutputPtr &output) const;
+    KScreen::Output::RgbRange getRgbRange(const QString &outputId, const QString &outputName) const;
+    void setRgbRange(const KScreen::OutputPtr &output, const KScreen::Output::RgbRange value);
+    void setRgbRange(const QString &outputId, const QString &outputName, const KScreen::Output::RgbRange value);
+
     QString dirPath() const override;
     QString filePath() const override;
 
@@ -150,6 +144,9 @@ public:
     KScreen::Output::VrrPolicy vrrPolicy() const;
     void setVrrPolicy(KScreen::Output::VrrPolicy value);
 
+    KScreen::Output::RgbRange rgbRange() const;
+    void setRgbRange(KScreen::Output::RgbRange value);
+
     QString dirPath() const override;
     QString filePath() const override;
 
